import React from 'react'
import HorizontalLine from './HorizontalLine'

const LocationDetails = ({
  distanceAirport, 
  distanceRailway, 
  distanceBusstand, 
  distanceHospital, 
  distanceSchool, 
  propertyAddress,
  //Developer
  developerPostAddress
}) => {
  const props = [
    {
      title: "Airport",
      image: "airplane",
      val: distanceAirport
    },
    {
      title: "Railway",
      image: "subway",
      val: distanceRailway
    },
    {
      title: "Bus Stand",
      image: "bus",
      val: distanceBusstand
    },
    {
      title: "Hospital",
      image: "hospital",
      val: distanceHospital
    },
    {
      title: "School",
      image: "school",
      val: distanceSchool
    }
  ]

  return (
    <div className='bg-white rounded-xl shadow-lg py-4 flex flex-col gap-4'>
      <p className='px-4 sm:px-6 font-semibold text-base sm:text-lg'>
        Location Details
      </p>
      <HorizontalLine />
      <p className='px-4 sm:px-6 font-semibold text-tertiary text-sm sm:text-xl text-balance'>
        {propertyAddress}
      </p>
      <div className="grid grid-cols-1 sm:grid-cols-2 gap-3 sm:gap-4 px-4 sm:px-6 bg-[#d9d9d9] sm:mx-6 rounded-lg py-4">
        {props.map(prop => (
          <div 
            className='
              bg-white 
              px-3 sm:px-6 
              py-2 
              justify-between 
              rounded-lg 
              flex 
              items-center 
              space-x-2 sm:space-x-4
            ' 
            key={prop.image}
          >
            <div className='flex-grow'>
              <p className='font-semibold text-xs sm:text-base'>{prop.title}</p>
              <p className='text-xs sm:text-sm text-tertiary'>
                {prop.val} KM
              </p>
            </div>
            <div 
              className='
                w-8 h-8 sm:w-10 sm:h-10 
                bg-brand 
                rounded-full 
                flex 
                items-center 
                justify-center
              '
            >
              <img 
                src={`/icons/${prop.image}.png`} 
                alt={`${prop.title} icon`} 
                className='w-4 h-4 sm:w-5 sm:h-5'
              />
            </div>
          </div>
        ))}
      </div>
    </div>
  )
}

export default LocationDetails